#ifdef GL_ES
precision mediump float;
#endif
 
varying vec4 v_fragmentColor;
varying vec2 v_texCoord;

uniform vec2 ImageSize;
uniform float OutlineWidth;
uniform vec4 OutlineColor;

bool checkEdge(vec2 texCoord)
{
	if(texCoord.x <= 0.0 || texCoord.x >= 1.0)return true;
	if(texCoord.y <= 0.0 || texCoord.y >= 1.0)return true;
	
	vec4 color = v_fragmentColor * texture2D(CC_Texture0, texCoord);
	if(color.a == 0.0)
	{
		return true;
	}else{
		return false;
	}
}

vec4 getColor()
{
	vec4 color = v_fragmentColor * texture2D(CC_Texture0, v_texCoord);
	if(color.a == 0.0)return color;

	vec2 pos = vec2(v_texCoord.x*ImageSize.x, v_texCoord.y*ImageSize.y);
	vec2 offset = vec2(0.0, 0.0);
	vec2 newTexCoord = vec2(0.0, 0.0);
	float minW = OutlineWidth*0.25;
	float maxW = OutlineWidth*0.75;
	
	//vec2 SinCosValue[12] = {vec2(0.000000,1.000000),vec2(0.500000,0.866026),vec2(0.866025,0.500001),vec2(1.000000,0.000001),
	//							vec2(0.866026,-0.499998),vec2(0.500002,-0.866024),vec2(0.000003,-1.000000),vec2(-0.499997,-0.866027),
	//							vec2(-0.866024,-0.500003),vec2(-1.000000,-0.000004),vec2(-0.866028,0.499996),vec2(-0.500004,0.866023)};
	vec2 SinCosValue[12];
	SinCosValue[0] = vec2(0.000000,1.000000);
	SinCosValue[1] = vec2(0.500000,0.866026);
	SinCosValue[2] = vec2(0.866025,0.500001);
	SinCosValue[3] = vec2(1.000000,0.000001);
	SinCosValue[4] = vec2(0.866026,-0.499998);
	SinCosValue[5] = vec2(0.500002,-0.866024);
	SinCosValue[6] = vec2(0.000003,-1.000000);
	SinCosValue[7] = vec2(-0.499997,-0.866027);
	SinCosValue[8] = vec2(-0.866024,-0.500003);
	SinCosValue[9] = vec2(-1.000000,-0.000004);
	SinCosValue[10] = vec2(-0.866028,0.499996);
	SinCosValue[11] = vec2(-0.500004,0.866023);
	
	for(float w = 1.0; w <= OutlineWidth; w += 1.0)
	{
		for(int i = 1; i < 12; i++)
		{
			offset = vec2(SinCosValue[i].x*w, SinCosValue[i].y*w);
			newTexCoord = vec2((pos.x + offset.x)/ImageSize.x, (pos.y + offset.y)/ImageSize.y);
			if(checkEdge(newTexCoord))
			{
				if(w >= minW && w <= maxW)
				{
					return OutlineColor;
				}
				else if(w < minW)
				{
					float percent = w/minW;
					return OutlineColor*percent;
				}else{
					float percent = (OutlineWidth - w)/minW;
					return OutlineColor*percent + color*(1.0 - percent);
				}
			}
		}
	}
	
	return color;
}

void main(void)
{
	gl_FragColor = getColor();
}
